# © 2020 Le Filament (<http://www.le-filament.com>)
# License AGPL-3.0 or later (http://www.gnu.org/licenses/agpl.html).

from odoo import api, fields, models


class AccountBankingMandateChange(models.TransientModel):
    _name = "account.banking.mandate.change.bordereau.wizard"
    _description = "Wizard changement mandat bordereaux"

    @api.model
    def _default_mandate_id(self):
        return self.env.context.get("active_id")

    @api.model
    def _default_bordereau_ids(self):
        bordereau_ids = (
            self.env["account.banking.mandate"]
            .browse(self.env.context.get("active_id"))
            ._select_open_bordereau()
        )
        return bordereau_ids

    mandate_id = fields.Many2one(
        comodel_name="account.banking.mandate",
        string="Mandat",
        default=_default_mandate_id,
        required=True,
    )
    partner_id = fields.Many2one(related="mandate_id.partner_id")
    bordereau_ids = fields.Many2many(
        relation="mandate_change_bordereau_wizard_scop_bordereau_rel",
        comodel_name="scop.bordereau",
        string="Bordereaux",
        default=_default_bordereau_ids,
    )

    def change_mandate(self):
        for bordereau in self.bordereau_ids:
            self.mandate_id._change_bordereau_mandate(bordereau)
