# Copyright 2021 Le Filament
# License AGPL-3.0 or later (https://www.gnu.org/licenses/agpl).

from odoo import _, api, fields, models
from odoo.exceptions import UserError


class ScopBordereauChangeLiasse(models.TransientModel):
    _name = "scop.bordereau.change.liasse.wizard"
    _description = "Changement de liasse sur le bordereau"

    bordereau_id = fields.Many2one(
        comodel_name="scop.bordereau",
        string="Bordereau",
        readonly=True,
    )
    partner_id = fields.Many2one(related="bordereau_id.partner_id")
    company_currency_id = fields.Many2one(related="bordereau_id.company_currency_id")

    # Ancienne liasse
    liasse_fiscale_id = fields.Many2one(related="bordereau_id.liasse_fiscale_id")
    amount_total_cotiz = fields.Monetary(
        related="bordereau_id.amount_total_cotiz",
        currency_field="company_currency_id",
    )
    amount_cg = fields.Float(
        "Cotisation CG Scop actuelle", compute="_compute_amount_cotiz"
    )
    amount_ur_med = fields.Float(
        "Cotisation UR Med actuelle", compute="_compute_amount_cotiz"
    )
    amount_ur_hdf = fields.Float(
        "Cotisation UR HDF actuelle", compute="_compute_amount_cotiz"
    )
    amount_ur_idf = fields.Float(
        "Cotisation UR IDF actuelle", compute="_compute_amount_cotiz"
    )
    amount_fede_com = fields.Float(
        "Cotisation Fede Com actuelle", compute="_compute_amount_cotiz"
    )
    amount_fede_cae = fields.Float(
        "Cotisation Fede CAE actuelle", compute="_compute_amount_cotiz"
    )
    amount_fede_indus = fields.Float(
        "Cotisation Fede Industrie actuelle", compute="_compute_amount_cotiz"
    )
    type_assiette = fields.Selection(
        string="Type d'assiette",
        related="bordereau_id.type_assiette",
    )
    montant_assiette = fields.Integer(
        string="Montant de l'assiette", related="bordereau_id.montant_assiette"
    )
    ca = fields.Float(related="bordereau_id.ca")
    va = fields.Float(related="bordereau_id.va")
    net_results = fields.Float(related="bordereau_id.net_results")
    wage_cg = fields.Float(related="bordereau_id.wage_cg")

    # Nouvelle liasse
    liasse_fiscale_new_id = fields.Many2one(
        comodel_name="scop.liasse.fiscale",
        string="Nouvelle liasse Fiscale",
    )
    amount_total_cotiz_new = fields.Monetary(
        string="Nouveau montant total de(s) cotisation(s)",
        currency_field="company_currency_id",
        readonly=1,
    )
    type_id_new = fields.Selection(
        string="Type de liasse", related="liasse_fiscale_new_id.type_id"
    )
    source_new = fields.Selection(
        string="Source de la liasse", related="liasse_fiscale_new_id.source"
    )
    amount_cg_new = fields.Float(
        "Cotisation CG Scop", related="liasse_fiscale_new_id.contribution_cg"
    )
    amount_ur_med_new = fields.Float(
        "Cotisation UR Méditerranée",
        related="liasse_fiscale_new_id.contribution_med",
    )
    amount_ur_hdf_new = fields.Float(
        "Cotisation UR HDF", related="liasse_fiscale_new_id.contribution_hdf"
    )
    amount_ur_idf_new = fields.Float(
        "Cotisation UR IDF", related="liasse_fiscale_new_id.contribution_idf"
    )
    amount_fede_com_new = fields.Float(
        "Cotisation Fédé Communication",
        related="liasse_fiscale_new_id.contribution_com",
    )
    amount_fede_cae_new = fields.Float(
        "Cotisation Fédé CAE", related="liasse_fiscale_new_id.contribution_cae"
    )
    amount_fede_indus_new = fields.Float(
        "Cotisation Fédé Industrie", related="liasse_fiscale_new_id.contribution_indus"
    )
    type_assiette_new = fields.Selection(
        related="liasse_fiscale_new_id.contribution_base_type"
    )
    montant_assiette_new = fields.Integer(
        related="liasse_fiscale_new_id.contribution_base_amount"
    )

    # ------------------------------------------------------
    # Compute
    # ------------------------------------------------------
    def _compute_amount_cotiz(self):
        type_cotisation_cg = self.env.ref("cgscop_partner.riga_14397").id
        type_cotisation_fede_com = self.env.ref("cgscop_partner.riga_14398").id
        type_cotisation_fede_cae = self.env.ref("cgscop_partner.cotiz_fede_cae").id
        type_cotisation_fede_indus = self.env.ref("cgscop_partner.cotiz_fede_indus").id
        type_cotisation_ur = self.env.ref("cgscop_partner.riga_14399").id
        for r in self:
            partner = r.bordereau_id.partner_id
            cotiz = r.bordereau_id.invoice_ids
            # CG
            cotiz_cg = cotiz.filtered(
                lambda i: i.type_contribution_id.id == type_cotisation_cg
            )
            r.amount_cg = sum(cotiz_cg.mapped("amount_total"))
            # Fede Com
            cotiz_fede_com = cotiz.filtered(
                lambda i: i.type_contribution_id.id == type_cotisation_fede_com
            )
            r.amount_fede_com = sum(cotiz_fede_com.mapped("amount_total"))
            # Fede CAE
            cotiz_fede_cae = cotiz.filtered(
                lambda i: i.type_contribution_id.id == type_cotisation_fede_cae
            )
            r.amount_fede_cae = sum(cotiz_fede_cae.mapped("amount_total"))
            # Fede Industrie
            cotiz_fede_indus = cotiz.filtered(
                lambda i: i.type_contribution_id.id == type_cotisation_fede_indus
            )
            r.amount_fede_indus = sum(cotiz_fede_indus.mapped("amount_total"))
            # UR HDF
            ur_hdf = self.env.ref("cgscop_partner.riga_14232").id
            if partner.ur_id.id == ur_hdf:
                cotiz_ur_hdf = cotiz.filtered(
                    lambda i: i.type_contribution_id.id == type_cotisation_ur
                )
                r.amount_ur_hdf = sum(cotiz_ur_hdf.mapped("amount_total"))
            else:
                r.amount_ur_hdf = 0

            # UR Med
            ur_med = self.env.ref("cgscop_partner.riga_14243").id
            if partner.ur_id.id == ur_med:
                cotiz_ur_med = cotiz.filtered(
                    lambda i: i.type_contribution_id.id == type_cotisation_ur
                )
                r.amount_ur_med = sum(cotiz_ur_med.mapped("amount_total"))
            else:
                r.amount_ur_med = 0

            # UR IDF
            ur_idf = self.env.ref("cgscop_partner.riga_14231").id
            if partner.ur_id.id == ur_idf:
                cotiz_ur_idf = cotiz.filtered(
                    lambda i: i.type_contribution_id.id == type_cotisation_ur
                )
                r.amount_ur_idf = sum(cotiz_ur_idf.mapped("amount_total"))
            else:
                r.amount_ur_idf = 0

    # ------------------------------------------------------
    # Onchange
    # ------------------------------------------------------
    @api.onchange("liasse_fiscale_new_id")
    def _compute_liasse_new_values(self):
        for r in self:
            if r.liasse_fiscale_new_id:
                r.amount_total_cotiz_new = (
                    r.amount_cg_new
                    + r.amount_ur_hdf_new
                    + r.amount_ur_med_new
                    + r.amount_ur_idf_new
                    + r.amount_fede_com_new
                    + r.amount_fede_cae_new
                    + r.amount_fede_indus_new
                )

    # ------------------------------------------------------
    # Action Button
    # ------------------------------------------------------
    def update_liasse_fiscale(self):
        bordereau_id = self.bordereau_id
        if not self.liasse_fiscale_new_id:
            raise UserError(_("Merci de choisir une nouvelle liasse fiscale."))
        # Link new liasse fiscale to bordereau
        bordereau_id.update(
            {
                "liasse_fiscale_id": self.liasse_fiscale_new_id,
            }
        )
        bordereau_id.create_cotiz_and_lines()
        return {"type": "ir.actions.act_window_close"}
