# Copyright 2020 Le Filament
# License AGPL-3.0 or later (https://www.gnu.org/licenses/agpl).

from odoo import api, fields, models


class ScopUpdateLiasseWizard(models.TransientModel):
    _name = "scop.update.liasse.wizard"
    _description = "Modification de la liasse des cotisations"

    bordereau_id = fields.Many2one(
        comodel_name="scop.bordereau",
        string="Bordereau",
        readonly=True,
    )
    partner_id = fields.Many2one(
        comodel_name="res.partner",
        string="Adhérent",
        readonly=True,
    )
    liasse_fiscale_id = fields.Many2one(
        comodel_name="scop.liasse.fiscale",
        string="Liasse Fiscale de référence",
        domain="[('partner_id', '=', partner_id), ('is_qualified', '=', True)]",
    )

    # ------------------------------------------------------
    # Override ORM
    # ------------------------------------------------------
    @api.model
    def default_get(self, fields):
        res = super(ScopUpdateLiasseWizard, self).default_get(fields)
        bordereau_id = self.env["scop.bordereau"].browse(
            self.env.context.get("active_id")
        )
        res.update(
            {
                "bordereau_id": bordereau_id.id,
                "partner_id": bordereau_id.partner_id.id,
                "liasse_fiscale_id": bordereau_id.liasse_fiscale_id.id,
            }
        )
        return res

    # ------------------------------------------------------
    # Action
    # ------------------------------------------------------
    def update_liasse(self):
        self.bordereau_id.update({"liasse_fiscale_id": self.liasse_fiscale_id})
